/** @file checkOrigami.x.cpp
 * Executable just loading an origami-file and computing some basic information.
 * 
 * @author Karsten Kremer
 * @version 1.0
 * @date 29.01.2007
 */

/*  This file is part of the Origami-Library, which is a collection
 *  of algorithms that calculate properties of mathematical objects
 *  called "origamis".
 *
 *  Copyright (C) 2007 Karsten Kremer
 *  Address: Institute for Algebra and Geometry, Fakultaet fuer
 *  Mathematik, Universitaet Karlsruhe, D-76128 Karlsruhe, Germany.
 *  E-mail: karsten.kremer@math.uni-karlsruhe.de
 *  or origami@math.uni-karlsruhe.de
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 3
 *  of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, see
 *  <http://www.gnu.org/licenses/> or write to the Free
 *  Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 *  Boston, MA  02110-1301, USA.
 *
 *  If you publish results you obtained by using this software please
 *  don't forget to give appropriate credit in your publication.
 */

#include <iostream>
#include <fstream>
#include <cstdio>
#include <cassert>
#include <list>

#include "freeGroups.cpp"
#include "path.cpp"
#include "graph.cpp"

using namespace std;



int main (int argc, char* argv[]) {
	if (argc < 2) {
		cout << "Please enter an origami-file (*.ori) as parameter." << endl;
		return 0;
	}
	Graph g(argv[1]);
	

	cout << "Origami:" << endl;
	cout << g;
	
	cout << "Number of Points: " << g.getNumberOfPoints() << endl;
	cout << "Genus: " << g.getGenus() << endl << endl;
	
	cout << "Commutator: " << g.getCommutator() << endl << endl;
	cout << "Ramification indices: " << g.getSignature() << endl << endl;
	
	SpanningTree t(g);
	cout << "Fundamental group (read from right to left): " << endl;
	cout <<  t.getFundamentalGroup() << endl;
	
	cout << "Relations: " << endl <<  t.getRelations() << endl;

	return 0;
}	
